@@ -25,5 +25,6 @@ def run_doctests(mod):
     import doctest
     extraglobs = {}
     if hasattr(mod, 'doctest_globals'): extraglobs = mod.doctest_globals()
-    return doctest.testmod(mod, extraglobs=extraglobs)
+    failed, attempted = doctest.testmod(mod, extraglobs=extraglobs)
+    assert failed == 0
 
