@@ -3,7 +3,10 @@ import cPickle as pickle
 import base64
 import logging
 import itertools
-from csc.divisi.dict_mixin import MyDictMixin as DictMixin # FIXME: divisi dependency
+from UserDict import DictMixin as DictMixin_
+
+# Hack: Make DictMixin a new-style class.
+class DictMixin(object, DictMixin_): pass
 
 def pkl_find_global(module_name, class_name):
     if module_name == 'csc.conceptnet4.analogyspace' and 'Tensor' in class_name:
@@ -41,6 +44,11 @@ def get_picklecached_thing(filename, func=None, name=None):
         f.close()
     return result
 
+# the short, 1-argument version that Rob wants because pickle.load
+# isn't easy enough
+def load_pickle(filename):
+    return get_picklecached_thing(filename)
+
 # List of things never to try to forward to the base object, because they're
 # just part of various dynamic introspection stuff. (er... IPython.)
 i2a_blacklist = set(('_getAttributeNames', 'trait_names'))
@@ -296,7 +304,9 @@ class PickleDict(DictMixin):
         if not os.path.isdir(self.dir):
             os.makedirs(self.dir)
         self.clear_cache()
-        if store_metadata: self['_meta']
+        if store_metadata:
+            self['_meta']
+            self.cleanup_meta()
 
     def __repr__(self):
         return 'PickleDict(%r)' % self.dir
@@ -449,6 +459,9 @@ class PickleDict(DictMixin):
     def __iter__(self):
         return (self.key_for_path(filename) for filename in os.listdir(self.dir) if filename != '_meta')
 
+    def keys(self):
+        return list(self.__iter__())
+
     def has_key(self, key):
         return (self.store_metadata and key == '_meta') or os.path.exists(self.path_for_key(key))
 
@@ -464,6 +477,14 @@ class PickleDict(DictMixin):
         meta_for_key[meta_key] = value
         meta[key] = meta_for_key
         
+    def cleanup_meta(self):
+        meta = self['_meta']
+        keys = set(self.iterkeys())
+        for m in meta.keys():
+            if m not in keys:
+                self.logger.info('Removing orphan metadata for %r' % m)
+                del meta[m]
+
     # this is the replacement for get_picklecached_thing:
     def get_lazy(self, key, thunk, version=None):
         if version is not None and not self.store_metadata:
